**Describe the change**
Please provide a clear and concise description and motivation of the proposed change.

**Linked issue**
If this pull request is related to an issue, please provide a link to the issue here.

**I have checked my changes are in line with the [Coding Standards](https://clinlp.readthedocs.io/en/latest/contributing.html#coding-standards)**
Yes/no

**I have added my changes to the `CHANGELOG.md` file**
Yes/no

**Any other relevant information**
Add any other context about the pull request here.
